****Replication Dofile - Helpful Organizations - Gabriele Spilker*********************
clear
clear matrix
set mem 500m

use "Helpful_IGOs.dta", clear

drop if income=="H"
drop if income=="H      "
tab income

xtset cowcode year

sort cowcode year
xi I.cowcode

**************************************************************************************************************************************
**********Table 2************
***Baseline Model in the paper 
set more off

xtpcse lnso2pclead igolax lgrgdpc polpos lopen FDIpcGDP  pop_den lgrow trend _Icowcode_*, c(ar)

xtpcse lnco2pclead igolax lgrgdpc polpos lopen FDIpcGDP   pop_den lgrow trend _Icowcode_*, c(ar) 

**************************************************************************************************************************************

***Disaggregating IGOs (institutionalization)

xtpcse lnso2pclead combinst1 combinst2 combinst3  lgrgdpc  polpos lopen FDIpcGDP pop_den lgrow trend _Icowcode_*, c(ar)

xtpcse lnco2pclead combinst1 combinst2 combinst3  lgrgdpc  polpos lopen FDIpcGDP   pop_den lgrow trend _Icowcode_*, c(ar)


**************************************************************************************************************************************
**********Table 3************
***Disaggregating IGOs (function)


#delimit;
xtpcse lnso2pclead EnvIGO GenIGO MilIGO EconIGO1 EconIGO2 EconIGO3 EconIGO4 SocIGO Agricultural  Nuclear
lgrgdpc polpos lopen FDIpcGDP   pop_den lgrow trend  _Icowcode_*, c(ar);
#delimit cr

#delimit;
xtpcse lnco2pclead EnvIGO GenIGO MilIGO EconIGO1 EconIGO2 EconIGO3 EconIGO4 SocIGO Agricultural  Nuclear
lgrgdpc polpos lopen FDIpcGDP  pop_den lgrow trend  _Icowcode_*, c(ar);
#delimit cr

**************************************************************************************************************************************
**********Table 5************
*********other IGO variables

xtpcse lnso2pc igostrict lgrgdpc polpos lopen FDIpcGDP   pop_den lgrow trend _Icowcode_*, c(ar)

xtpcse lnco2pc igostrict lgrgdpc polpos lopen FDIpcGDP   pop_den lgrow trend _Icowcode_*, c(ar) 

xtpcse lnso2pc  igomiddle lgrgdpc polpos lopen FDIpcGDP  pop_den lgrow trend _Icowcode_*, c(ar)

xtpcse lnco2pc  igomiddle  lgrgdpc polpos lopen FDIpcGDP   pop_den lgrow trend _Icowcode_*, c(ar) 


***deviation from mean of IGO

xtpcse lnso2pc devIGO lgrgdpc polpos lopen FDIpcGDP  pop_den lgrow trend _Icowcode_*, c(ar)

xtpcse lnco2pc devIGO lgrgdpc polpos lopen FDIpcGDP  pop_den lgrow trend _Icowcode_*, c(ar) 


**************************************************************************************************************************************
**Table 6: Robustness Checks
***try whether democracy dummy makes a difference

set more off
xtpcse lnso2pclead igolax lgrgdpc democracy lopen FDIpcGDP  pop_den lgrow trend _Icowcode_*, c(ar) 

set more off
xtpcse lnco2pclead igolax lgrgdpc democracy lopen FDIpcGDP pop_den lgrow trend _Icowcode_*, c(ar) 


***use BDM’s measure of selectorate size

set more off
xtpcse lnso2pclead igolax lgrgdpc bdm_w_s lopen FDIpcGDP  pop_den lgrow trend _Icowcode_*, c(ar) 

set more off
xtpcse lnco2pclead igolax lgrgdpc bdm_w_s lopen FDIpcGDP pop_den lgrow trend _Icowcode_*, c(ar) 


**************************************************************************************************************************************
**********Table 4************
***Disaggregating IGOs (function) across different samples

use "Helpful_IGOs.dta", clear

tab income

xtset cowcode year

sort cowcode year
xi I.cowcode


#delimit;
xtpcse lnso2pclead EnvIGO GenIGO MilIGO EconIGO1 EconIGO2 EconIGO3 EconIGO4 SocIGO Agricultural  Nuclear
lgrgdpc polpos lopen FDIpcGDP   pop_den lgrow trend  _Icowcode_*, c(ar);
#delimit cr

set more off
#delimit;
xtpcse lnco2pclead EnvIGO GenIGO MilIGO EconIGO1 EconIGO2 EconIGO3 EconIGO4 SocIGO Agricultural  Nuclear
lgrgdpc polpos lopen FDIpcGDP  pop_den lgrow trend  _Icowcode_*, c(ar);
#delimit cr

drop if income=="H"
drop if income=="H      "
tab income

#delimit;
xtpcse lnso2pclead EnvIGO GenIGO MilIGO EconIGO1 EconIGO2 EconIGO3 EconIGO4 SocIGO Agricultural  Nuclear
lgrgdpc polpos lopen FDIpcGDP   pop_den lgrow trend  _Icowcode_*, c(ar);
#delimit cr

set more off
#delimit;
xtpcse lnco2pclead EnvIGO GenIGO MilIGO EconIGO1 EconIGO2 EconIGO3 EconIGO4 SocIGO Agricultural  Nuclear
lgrgdpc polpos lopen FDIpcGDP  pop_den lgrow trend  _Icowcode_*, c(ar);
#delimit cr


drop if income=="UM"
tab income
set more off
#delimit;
xtpcse lnso2pclead EnvIGO GenIGO MilIGO EconIGO1 EconIGO2 EconIGO3 EconIGO4 SocIGO Agricultural  Nuclear
lgrgdpc polpos lopen FDIpcGDP   pop_den lgrow trend  _Icowcode_*, c(ar);
#delimit cr

#delimit;
xtpcse lnco2pclead EnvIGO GenIGO MilIGO EconIGO1 EconIGO2 EconIGO3 EconIGO4 SocIGO Agricultural  Nuclear
lgrgdpc polpos lopen FDIpcGDP  pop_den lgrow trend  _Icowcode_*, c(ar);
#delimit cr



**************************************************************************************************************************************
**********Table 1************
***Descriptive Statistics

use "Helpful_IGOs.dta", clear

drop if income=="H"
drop if income=="H      "
tab income


xtsum igolax if lnco2pclead!=.  & polpos!=. & lopen!=. & FDIpcGDP!=. & lgrgdpc!=. & pop_den!=. & lgrow!=. 
xtsum grgdpc if   polpos!=. & igolax!=. & lnco2pclead !=. & FDIpcGDP!=. & lopen!=. & pop_den!=. & lgrow!=.
xtsum polpos if lnco2pclead!=.  & igolax!=. & lopen!=. & FDIpcGDP!=. & lgrgdpc!=. & pop_den!=. & lgrow!=.
xtsum bdm_w_s if igolax!=. & lopen!=. & FDIpcGDP!=. & lgrgdpc!=. & pop_den!=. & lgrow!=. & lnco2pclead!=. & polpos!=.
xtsum lopen if polpos!=. & igolax!=. & lnco2pclead !=. & FDIpcGDP!=. & lgrgdpc!=. & pop_den!=. & lgrow!=.
xtsum FDIpcGDP if   polpos!=. & igolax!=. & lnco2pclead !=. & lopen!=. & lgrgdpc!=. & pop_den!=. & lgrow!=.
xtsum pop_den if   polpos!=. & igolax!=. & lnco2pclead !=. & FDIpcGDP!=. & lgrgdpc!=. & lopen!=. & lgrow!=.
xtsum grow if   polpos!=. & igolax!=. & lnco2pclead !=. & FDIpcGDP!=. & lgrgdpc!=. & pop_den!=. & lopen!=.


sort cowcode year
by cowcode: gen so2pclead = so2pc[_n+1]
replace so2pclead=so2pclead*1000
sum so2pclead  if  polpos!=. & igolax!=. & lopen!=. & FDIpcGDP!=. & lgrgdpc!=. & pop_den!=. & lgrow!=.

sort cowcode year
by cowcode: gen co2pclead = CO2[_n+1]
xtsum co2pclead  if   polpos!=. & igolax!=. & lopen!=. & FDIpcGDP!=. & lgrgdpc!=. & pop_den!=. & lgrow!=.
